"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getCustomWebpackVersion = exports.setup = exports.ngAdd = void 0;
const tasks_1 = require("@angular-devkit/schematics/tasks");
const utils_1 = require("../utils");
function ngAdd(options) {
    return (host, context) => {
        const ngCoreVersionTag = utils_1.getPackageVersionFromPackageJson(host, '@angular/core');
        const angularDependencyVersion = ngCoreVersionTag || `0.0.0-NG`;
        const packageName = 'angular-custom-webpack-chaining';
        const version = getCustomWebpackVersion(angularDependencyVersion);
        utils_1.addPackageToPackageJson(host, packageName, version, 'devDependencies');
        const installTask = context.addTask(new tasks_1.NodePackageInstallTask());
        const addCustomWebpack = context.addTask(new tasks_1.RunSchematicTask(packageName, 'ng-add-custom-webpack', Object.assign(Object.assign({}, options), { path: 'extra-webpack.config.js' })), [installTask]);
        context.addTask(new tasks_1.RunSchematicTask('setup', options), [addCustomWebpack]);
    };
}
exports.ngAdd = ngAdd;
function setup(options) {
    return (host) => utils_1.setAllCustomWebpackChainingToAngularJson(host, options.project);
}
exports.setup = setup;
function getCustomWebpackVersion(version) {
    const [major, minor] = utils_1.parseVersion(version);
    switch (major) {
        case '10': return '~0.1000.x';
        case '11': return '~0.1100.x';
        case '12': return '~0.1200.x';
        default: throw new Error(`custom-webpack chaining is not support Angular ${version}.`);
    }
}
exports.getCustomWebpackVersion = getCustomWebpackVersion;
//# sourceMappingURL=index.js.map